@@ -21,6 +21,7 @@
 
 import os
 import shutil
+import subprocess  # nosec
 import sys
 
 import click
@@ -35,6 +36,7 @@ from aea.cli.common import (
 from aea.configurations.base import (
     DEFAULT_AEA_CONFIG_FILE,
     ProtocolSpecification,
+    ProtocolSpecificationParseError,
     PublicId,
 )
 from aea.configurations.loader import ConfigLoader
@@ -50,13 +52,21 @@ def generate(ctx: Context):
 
 def _generate_item(ctx: Context, item_type, specification_path):
     """Generate an item based on a specification and add it to the configuration file and agent."""
-    # # check protocol buffer compiler is installed
-    # res = shutil.which("protoc")
-    # if res is None:
-    #     print(
-    #         "Please install protocol buffer first! See the following link: https://developers.google.com/protocol-buffers/"
-    #     )
-    #     sys.exit(1)
+    # check protocol buffer compiler is installed
+    res = shutil.which("protoc")
+    if res is None:
+        logger.error(
+            "Please install protocol buffer first! See the following link: https://developers.google.com/protocol-buffers/"
+        )
+        sys.exit(1)
+
+    # check black code formatter is installed
+    res = shutil.which("black")
+    if res is None:
+        logger.error(
+            "Please install black code formater first! See the following link: https://black.readthedocs.io/en/stable/installation_and_usage.html"
+        )
+        sys.exit(1)
 
     # Get existing items
     existing_id_list = getattr(ctx.agent_config, "{}s".format(item_type))
@@ -129,12 +139,42 @@ def _generate_item(ctx: Context, item_type, specification_path):
             )
         )
         sys.exit(1)
-    except Exception as e:
-        logger.exception(e)
+    except ProtocolSpecificationParseError as e:
+        logger.error(
+            "The following error happened while parsing the protocol specification: "
+            + str(e)
+        )
         shutil.rmtree(
             os.path.join(item_type_plural, protocol_spec.name), ignore_errors=True
         )
         sys.exit(1)
+    except Exception as e:
+        logger.debug("Exception thrown: " + str(e))
+        logger.error(
+            "There was an error while generating the protocol. The protocol is NOT generated."
+        )
+        shutil.rmtree(
+            os.path.join(item_type_plural, protocol_spec.name), ignore_errors=True
+        )
+        sys.exit(1)
+
+    # Run black code formatting
+    try:
+        subp = subprocess.Popen(  # nosec
+            [
+                sys.executable,
+                "-m",
+                "black",
+                os.path.join(item_type_plural, protocol_spec.name),
+                "--quiet",
+            ]
+        )
+        subp.wait(10.0)
+    finally:
+        poll = subp.poll()
+        if poll is None:  # pragma: no cover
+            subp.terminate()
+            subp.wait(5)
 
 
 @generate.command()
