@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # ------------------------------------------------------------------------------
 #
 #   Copyright 2018-2019 Fetch.AI Limited
@@ -8,7 +7,7 @@
 #   you may not use this file except in compliance with the License.
 #   You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
+#       http://www.apache.org/licenses/LICENSE-2.0
 #
 #   Unless required by applicable law or agreed to in writing, software
 #   distributed under the License is distributed on an "AS IS" BASIS,
@@ -19,17 +18,17 @@
 # ------------------------------------------------------------------------------
 
 """Module wrapping all the public and private keys cryptography."""
+
 from typing import Dict, cast
 
 from aea.crypto.base import Crypto
-from aea.crypto.default import DefaultCrypto, DEFAULT
-from aea.crypto.ethereum import EthereumCrypto, ETHEREUM
-from aea.crypto.fetchai import FetchAICrypto, FETCHAI
+from aea.crypto.ethereum import ETHEREUM, EthereumCrypto
+from aea.crypto.fetchai import FETCHAI, FetchAICrypto
 
-SUPPORTED_CRYPTOS = [DEFAULT, ETHEREUM, FETCHAI]
+SUPPORTED_CRYPTOS = [ETHEREUM, FETCHAI]
 
 
-class Wallet(object):
+class Wallet:
     """Store all the cryptos we initialise."""
 
     def __init__(self, private_key_paths: Dict[str, str]):
@@ -43,9 +42,7 @@ class Wallet(object):
         addresses = {}  # type: Dict[str, str]
 
         for identifier, path in private_key_paths.items():
-            if identifier == DEFAULT:
-                crypto_objects[identifier] = DefaultCrypto(path)
-            elif identifier == FETCHAI:
+            if identifier == FETCHAI:
                 crypto_objects[identifier] = FetchAICrypto(path)
             elif identifier == ETHEREUM:
                 crypto_objects[identifier] = EthereumCrypto(path)
