@@ -18,6 +18,8 @@
 # ------------------------------------------------------------------------------
 
 """Useful classes for the OEF search."""
+
+import pickle  # nosec
 from abc import ABC, abstractmethod
 from copy import deepcopy
 from enum import Enum
@@ -108,6 +110,35 @@ class Description:
         """Create an iterator."""
         return iter(self.values)
 
+    @classmethod
+    def encode(
+        cls, performative_content, description_from_message: "Description"
+    ) -> None:
+        """
+        Encode an instance of this class into the protocol buffer object.
+
+        The content in the 'performative_content' argument must be matched with the message content in the 'description_from_message' argument.
+
+        :param performative_content: the performative protocol buffer object containing a content whose type is this class.
+        :param description_from_message: the message content to be encoded in the protocol buffer object.
+        :return: None
+        """
+        description_from_message_bytes = pickle.dumps(description_from_message)  # nosec
+        performative_content.description = description_from_message_bytes
+
+    @classmethod
+    def decode(cls, description_from_pb2) -> "Description":
+        """
+        Decode a protocol buffer object that corresponds with this class into an instance of this class.
+
+        A new instance of this class must be created that matches the content in the 'description_from_pb2' argument.
+
+        :param description_from_pb2: the protocol buffer content object whose type corresponds with this class.
+        :return: A new instance of this class that matches the protocol buffer object in the 'description_from_pb2' argument.
+        """
+        service_description = pickle.loads(description_from_pb2.description)  # nosec
+        return service_description
+
 
 class ConstraintTypes(Enum):
     """Types of constraint."""
@@ -448,3 +479,30 @@ class Query:
             and self.constraints == other.constraints
             and self.model == other.model
         )
+
+    @classmethod
+    def encode(cls, performative_content, query_from_message: "Query") -> None:
+        """
+        Encode an instance of this class into the protocol buffer object.
+
+        The content in the 'performative_content' argument must be matched with the message content in the 'query_from_message' argument.
+
+        :param performative_content: the performative protocol buffer object containing a content whose type is this class.
+        :param query_from_message: the message content to be encoded in the protocol buffer object.
+        :return: None
+        """
+        query_bytes = pickle.dumps(query_from_message)  # nosec
+        performative_content.query_bytes = query_bytes
+
+    @classmethod
+    def decode(cls, query_from_pb2) -> "Query":
+        """
+        Decode a protocol buffer object that corresponds with this class into an instance of this class.
+
+        A new instance of this class must be created that matches the content in the 'query_from_pb2' argument.
+
+        :param query_from_pb2: the protocol buffer content object whose type corresponds with this class.
+        :return: A new instance of this class that matches the protocol buffer object in the 'query_from_pb2' argument.
+        """
+        query = pickle.loads(query_from_pb2.query_bytes)  # nosec
+        return query
