@@ -31,12 +31,16 @@ from aea.helpers.search.models import (
     Query,
 )
 from aea.mail.base import AEAConnectionError, Envelope, InBox, Multiplexer
+from aea.protocols.default.message import DefaultMessage
+from aea.protocols.default.serialization import DefaultSerializer
 
 from packages.fetchai.connections.local.connection import LocalNode, OEFLocalConnection
-from packages.fetchai.protocols.fipa.message import FIPAMessage
-from packages.fetchai.protocols.fipa.serialization import FIPASerializer
-from packages.fetchai.protocols.oef.message import OEFMessage
-from packages.fetchai.protocols.oef.serialization import DEFAULT_OEF, OEFSerializer
+from packages.fetchai.protocols.fipa.message import FipaMessage
+from packages.fetchai.protocols.fipa.serialization import FipaSerializer
+from packages.fetchai.protocols.oef_search.message import OefSearchMessage
+from packages.fetchai.protocols.oef_search.serialization import OefSearchSerializer
+
+DEFAULT_OEF = "default_oef"
 
 
 class TestEmptySearch:
@@ -67,47 +71,28 @@ class TestEmptySearch:
         query = Query(constraints=[], model=None)
 
         # build and send the request
-        search_services_request = OEFMessage(
-            type=OEFMessage.Type.SEARCH_SERVICES, id=request_id, query=query
+        search_services_request = OefSearchMessage(
+            performative=OefSearchMessage.Performative.SEARCH_SERVICES,
+            dialogue_reference=(str(request_id), ""),
+            query=query,
         )
-        msg_bytes = OEFSerializer().encode(search_services_request)
+        msg_bytes = OefSearchSerializer().encode(search_services_request)
         envelope = Envelope(
             to=DEFAULT_OEF,
             sender=self.address_1,
-            protocol_id=OEFMessage.protocol_id,
+            protocol_id=OefSearchMessage.protocol_id,
             message=msg_bytes,
         )
         self.multiplexer.put(envelope)
 
         # check the result
         response_envelope = self.multiplexer.get(block=True, timeout=2.0)
-        assert response_envelope.protocol_id == OEFMessage.protocol_id
+        assert response_envelope.protocol_id == OefSearchMessage.protocol_id
         assert response_envelope.to == self.address_1
         assert response_envelope.sender == DEFAULT_OEF
-        search_result = OEFSerializer().decode(response_envelope.message)
-        assert search_result.get("type") == OEFMessage.Type.SEARCH_RESULT
-        assert search_result.get("agents") == []
-
-        # build and send the request
-        search_agents_request = OEFMessage(
-            type=OEFMessage.Type.SEARCH_AGENTS, id=request_id, query=query
-        )
-        msg_bytes = OEFSerializer().encode(search_agents_request)
-        envelope = Envelope(
-            to=DEFAULT_OEF,
-            sender=self.address_1,
-            protocol_id=OEFMessage.protocol_id,
-            message=msg_bytes,
-        )
-        self.multiplexer.put(envelope)
-
-        # check the result
-        response_envelope = self.multiplexer.get(block=True, timeout=5.0)
-        assert response_envelope.protocol_id == OEFMessage.protocol_id
-        assert response_envelope.sender == DEFAULT_OEF
-        search_result = OEFSerializer().decode(response_envelope.message)
-        assert search_result.get("type") == OEFMessage.Type.SEARCH_RESULT
-        assert search_result.get("agents") == []
+        search_result = OefSearchSerializer().decode(response_envelope.message)
+        assert search_result.performative == OefSearchMessage.Performative.SEARCH_RESULT
+        assert search_result.agents == ()
 
     @classmethod
     def teardown_class(cls):
@@ -140,22 +125,20 @@ class TestSimpleSearchResult:
 
         # register a service.
         request_id = 1
-        service_id = ""
         cls.data_model = DataModel("foobar", attributes=[])
         service_description = Description(
             {"foo": 1, "bar": "baz"}, data_model=cls.data_model
         )
-        register_service_request = OEFMessage(
-            type=OEFMessage.Type.REGISTER_SERVICE,
-            id=request_id,
+        register_service_request = OefSearchMessage(
+            performative=OefSearchMessage.Performative.REGISTER_SERVICE,
+            dialogue_reference=(str(request_id), ""),
             service_description=service_description,
-            service_id=service_id,
         )
-        msg_bytes = OEFSerializer().encode(register_service_request)
+        msg_bytes = OefSearchSerializer().encode(register_service_request)
         envelope = Envelope(
             to=DEFAULT_OEF,
             sender=cls.address_1,
-            protocol_id=OEFMessage.protocol_id,
+            protocol_id=OefSearchMessage.protocol_id,
             message=msg_bytes,
         )
         cls.multiplexer.put(envelope)
@@ -166,26 +149,28 @@ class TestSimpleSearchResult:
         query = Query(constraints=[], model=self.data_model)
 
         # build and send the request
-        search_services_request = OEFMessage(
-            type=OEFMessage.Type.SEARCH_SERVICES, id=request_id, query=query
+        search_services_request = OefSearchMessage(
+            performative=OefSearchMessage.Performative.SEARCH_SERVICES,
+            dialogue_reference=(str(request_id), ""),
+            query=query,
         )
-        msg_bytes = OEFSerializer().encode(search_services_request)
+        msg_bytes = OefSearchSerializer().encode(search_services_request)
         envelope = Envelope(
             to=DEFAULT_OEF,
             sender=self.address_1,
-            protocol_id=OEFMessage.protocol_id,
+            protocol_id=OefSearchMessage.protocol_id,
             message=msg_bytes,
         )
         self.multiplexer.put(envelope)
 
         # check the result
         response_envelope = self.multiplexer.get(block=True, timeout=2.0)
-        assert response_envelope.protocol_id == OEFMessage.protocol_id
+        assert response_envelope.protocol_id == OefSearchMessage.protocol_id
         assert response_envelope.to == self.address_1
         assert response_envelope.sender == DEFAULT_OEF
-        search_result = OEFSerializer().decode(response_envelope.message)
-        assert search_result.get("type") == OEFMessage.Type.SEARCH_RESULT
-        assert search_result.get("agents") == [self.address_1]
+        search_result = OefSearchSerializer().decode(response_envelope.message)
+        assert search_result.performative == OefSearchMessage.Performative.SEARCH_RESULT
+        assert search_result.agents == (self.address_1,)
 
     @classmethod
     def teardown_class(cls):
@@ -232,190 +217,104 @@ class TestUnregister:
         service_description = Description(
             {"foo": 1, "bar": "baz"}, data_model=data_model
         )
-        msg = OEFMessage(
-            type=OEFMessage.Type.UNREGISTER_SERVICE,
-            id=0,
+        msg = OefSearchMessage(
+            performative=OefSearchMessage.Performative.UNREGISTER_SERVICE,
+            dialogue_reference=(str(1), ""),
             service_description=service_description,
-            service_id="Test_service",
         )
-        msg_bytes = OEFSerializer().encode(msg)
+        msg_bytes = OefSearchSerializer().encode(msg)
         envelope = Envelope(
             to=DEFAULT_OEF,
             sender=self.address_1,
-            protocol_id=OEFMessage.protocol_id,
+            protocol_id=OefSearchMessage.protocol_id,
             message=msg_bytes,
         )
         self.multiplexer1.put(envelope)
 
         # check the result
         response_envelope = self.multiplexer1.get(block=True, timeout=5.0)
-        assert response_envelope.protocol_id == OEFMessage.protocol_id
+        assert response_envelope.protocol_id == OefSearchMessage.protocol_id
         assert response_envelope.sender == DEFAULT_OEF
-        result = OEFSerializer().decode(response_envelope.message)
-        assert result.get("type") == OEFMessage.Type.OEF_ERROR
+        result = OefSearchSerializer().decode(response_envelope.message)
+        assert result.performative == OefSearchMessage.Performative.OEF_ERROR
 
-        msg = OEFMessage(
-            type=OEFMessage.Type.REGISTER_SERVICE,
-            id=0,
+        msg = OefSearchMessage(
+            performative=OefSearchMessage.Performative.REGISTER_SERVICE,
+            dialogue_reference=(str(1), ""),
             service_description=service_description,
-            service_id="Test_Service",
         )
-        msg_bytes = OEFSerializer().encode(msg)
+        msg_bytes = OefSearchSerializer().encode(msg)
         envelope = Envelope(
             to=DEFAULT_OEF,
             sender=self.address_1,
-            protocol_id=OEFMessage.protocol_id,
+            protocol_id=OefSearchMessage.protocol_id,
             message=msg_bytes,
         )
         self.multiplexer1.put(envelope)
 
-        # Search for the register agent
-        msg = OEFMessage(
-            type=OEFMessage.Type.SEARCH_AGENTS,
-            id=0,
+        # Search for the registered service
+        msg = OefSearchMessage(
+            performative=OefSearchMessage.Performative.SEARCH_SERVICES,
+            dialogue_reference=(str(1), ""),
             query=Query([Constraint("foo", ConstraintType("==", 1))]),
         )
-        msg_bytes = OEFSerializer().encode(msg)
+        msg_bytes = OefSearchSerializer().encode(msg)
         envelope = Envelope(
             to=DEFAULT_OEF,
             sender=self.address_1,
-            protocol_id=OEFMessage.protocol_id,
+            protocol_id=OefSearchMessage.protocol_id,
             message=msg_bytes,
         )
         self.multiplexer1.put(envelope)
         # check the result
         response_envelope = self.multiplexer1.get(block=True, timeout=5.0)
-        assert response_envelope.protocol_id == OEFMessage.protocol_id
+        assert response_envelope.protocol_id == OefSearchMessage.protocol_id
         assert response_envelope.sender == DEFAULT_OEF
-        result = OEFSerializer().decode(response_envelope.message)
-        assert result.get("type") == OEFMessage.Type.SEARCH_RESULT
-        assert len(result.get("agents")) == 1
+        result = OefSearchSerializer().decode(response_envelope.message)
+        assert result.performative == OefSearchMessage.Performative.SEARCH_RESULT
+        assert len(result.agents) == 1
 
         # unregister the service
         data_model = DataModel("foobar", attributes=[])
         service_description = Description(
             {"foo": 1, "bar": "baz"}, data_model=data_model
         )
-        msg = OEFMessage(
-            type=OEFMessage.Type.UNREGISTER_SERVICE,
-            id=0,
+        msg = OefSearchMessage(
+            performative=OefSearchMessage.Performative.UNREGISTER_SERVICE,
+            dialogue_reference=(str(1), ""),
             service_description=service_description,
-            service_id="Test_service",
         )
-        msg_bytes = OEFSerializer().encode(msg)
+        msg_bytes = OefSearchSerializer().encode(msg)
         envelope = Envelope(
             to=DEFAULT_OEF,
             sender=self.address_1,
-            protocol_id=OEFMessage.protocol_id,
+            protocol_id=OefSearchMessage.protocol_id,
             message=msg_bytes,
         )
         self.multiplexer1.put(envelope)
 
         # the same query returns empty
         # Search for the register agent
-        msg = OEFMessage(
-            type=OEFMessage.Type.SEARCH_AGENTS,
-            id=0,
+        msg = OefSearchMessage(
+            performative=OefSearchMessage.Performative.SEARCH_SERVICES,
+            dialogue_reference=(str(1), ""),
             query=Query([Constraint("foo", ConstraintType("==", 1))]),
         )
-        msg_bytes = OEFSerializer().encode(msg)
+        msg_bytes = OefSearchSerializer().encode(msg)
         envelope = Envelope(
             to=DEFAULT_OEF,
             sender=self.address_1,
-            protocol_id=OEFMessage.protocol_id,
+            protocol_id=OefSearchMessage.protocol_id,
             message=msg_bytes,
         )
         self.multiplexer1.put(envelope)
         # check the result
         response_envelope = self.multiplexer1.get(block=True, timeout=5.0)
-        assert response_envelope.protocol_id == OEFMessage.protocol_id
+        assert response_envelope.protocol_id == OefSearchMessage.protocol_id
         assert response_envelope.sender == DEFAULT_OEF
-        result = OEFSerializer().decode(response_envelope.message)
-        assert result.get("type") == OEFMessage.Type.SEARCH_RESULT
-        assert len(result.get("agents")) == 0
-
-    def test_search_agent(self):
-        """Test the registered agents, we will not find any."""
-        data_model = DataModel("foobar", attributes=[])
-        agent_description = Description({"foo": 1, "bar": "baz"}, data_model=data_model)
-        query = Query(constraints=[], model=data_model)
-
-        # Register an agent
-        msg = OEFMessage(
-            type=OEFMessage.Type.REGISTER_AGENT,
-            id=0,
-            agent_description=agent_description,
-            agent_id="Test_agent",
-        )
-        msg_bytes = OEFSerializer().encode(msg)
-        envelope = Envelope(
-            to=DEFAULT_OEF,
-            sender=self.address_1,
-            protocol_id=OEFMessage.protocol_id,
-            message=msg_bytes,
-        )
-        self.multiplexer1.put(envelope)
-
-        time.sleep(0.1)
-
-        # Search for the register agent
-        msg = OEFMessage(type=OEFMessage.Type.SEARCH_AGENTS, id=0, query=query)
-        msg_bytes = OEFSerializer().encode(msg)
-        envelope = Envelope(
-            to=DEFAULT_OEF,
-            sender=self.address_2,
-            protocol_id=OEFMessage.protocol_id,
-            message=msg_bytes,
-        )
-        self.multiplexer2.put(envelope)
-
-        # check the result
-        response_envelope = self.multiplexer2.get(block=True, timeout=5.0)
-        assert response_envelope.protocol_id == OEFMessage.protocol_id
-        assert response_envelope.sender == DEFAULT_OEF
-        result = OEFSerializer().decode(response_envelope.message)
-        assert len(result.get("agents")) == 1, "There are registered agents!"
-
-        # Send unregister message.
-        msg = OEFMessage(
-            type=OEFMessage.Type.UNREGISTER_AGENT,
-            id=0,
-            agent_description=agent_description,
-            agent_id="Test_agent",
-        )
-        msg_bytes = OEFSerializer().encode(msg)
-        envelope = Envelope(
-            to=DEFAULT_OEF,
-            sender=self.address_1,
-            protocol_id=OEFMessage.protocol_id,
-            message=msg_bytes,
-        )
-        self.multiplexer1.put(envelope)
-
-        time.sleep(0.1)
-
-        # Trigger error message.
-        msg = OEFMessage(
-            type=OEFMessage.Type.UNREGISTER_AGENT,
-            id=0,
-            agent_description=agent_description,
-            agent_id="Unknown_Agent",
-        )
-        msg_bytes = OEFSerializer().encode(msg)
-        envelope = Envelope(
-            to=DEFAULT_OEF,
-            sender=self.address_1,
-            protocol_id=OEFMessage.protocol_id,
-            message=msg_bytes,
-        )
-        self.multiplexer1.put(envelope)
-
-        # check the result
-        response_envelope = self.multiplexer1.get(block=True, timeout=5.0)
-        assert response_envelope.protocol_id == OEFMessage.protocol_id
-        assert response_envelope.sender == DEFAULT_OEF
-        result = OEFSerializer().decode(response_envelope.message)
-        assert result.get("type") == OEFMessage.Type.OEF_ERROR
+        result = OefSearchSerializer().decode(response_envelope.message)
+        assert result.performative == OefSearchMessage.Performative.SEARCH_RESULT
+        assert result.agents == ()
 
     @classmethod
     def teardown_class(cls):
@@ -448,12 +347,18 @@ class TestAgentMessage:
     @pytest.mark.asyncio
     async def test_messages(self):
         """Test that at the beginning, the search request returns an empty search result."""
-        msg = FIPAMessage((str(0), ""), 0, 0, FIPAMessage.Performative.CFP, query=None)
-        msg_bytes = FIPASerializer().encode(msg)
+        msg = FipaMessage(
+            performative=FipaMessage.Performative.CFP,
+            dialogue_reference=(str(0), ""),
+            message_id=1,
+            target=0,
+            query=Query([Constraint("something", ConstraintType(">", 1))]),
+        )
+        msg_bytes = FipaSerializer().encode(msg)
         envelope = Envelope(
             to=DEFAULT_OEF,
             sender=self.address_1,
-            protocol_id=FIPAMessage.protocol_id,
+            protocol_id=FipaMessage.protocol_id,
             message=msg_bytes,
         )
         with pytest.raises(AEAConnectionError):
@@ -464,24 +369,28 @@ class TestAgentMessage:
             ).send(envelope)
 
         self.multiplexer1.connect()
-        msg = FIPAMessage(
-            (str(0), str(1)), 0, 0, FIPAMessage.Performative.CFP, query=None
+        msg = FipaMessage(
+            performative=FipaMessage.Performative.CFP,
+            dialogue_reference=(str(0), str(1)),
+            message_id=1,
+            target=0,
+            query=Query([Constraint("something", ConstraintType(">", 1))]),
         )
-        msg_bytes = FIPASerializer().encode(msg)
+        msg_bytes = FipaSerializer().encode(msg)
         envelope = Envelope(
             to="this_address_does_not_exist",
             sender=self.address_1,
-            protocol_id=FIPAMessage.protocol_id,
+            protocol_id=FipaMessage.protocol_id,
             message=msg_bytes,
         )
         self.multiplexer1.put(envelope)
 
         # check the result
         response_envelope = self.multiplexer1.get(block=True, timeout=5.0)
-        assert response_envelope.protocol_id == OEFMessage.protocol_id
+        assert response_envelope.protocol_id == DefaultMessage.protocol_id
         assert response_envelope.sender == DEFAULT_OEF
-        result = OEFSerializer().decode(response_envelope.message)
-        assert result.get("type") == OEFMessage.Type.DIALOGUE_ERROR
+        result = DefaultSerializer().decode(response_envelope.message)
+        assert result.performative == DefaultMessage.Performative.ERROR
 
     @classmethod
     def teardown_class(cls):
@@ -547,22 +456,20 @@ class TestFilteredSearchResult:
 
         # register 'multiplexer1' as a service 'foobar'.
         request_id = 1
-        service_id = ""
         cls.data_model_foobar = DataModel("foobar", attributes=[])
         service_description = Description(
             {"foo": 1, "bar": "baz"}, data_model=cls.data_model_foobar
         )
-        register_service_request = OEFMessage(
-            type=OEFMessage.Type.REGISTER_SERVICE,
-            id=request_id,
+        register_service_request = OefSearchMessage(
+            performative=OefSearchMessage.Performative.REGISTER_SERVICE,
+            dialogue_reference=(str(request_id), ""),
             service_description=service_description,
-            service_id=service_id,
         )
-        msg_bytes = OEFSerializer().encode(register_service_request)
+        msg_bytes = OefSearchSerializer().encode(register_service_request)
         envelope = Envelope(
             to=DEFAULT_OEF,
             sender=cls.address_1,
-            protocol_id=OEFMessage.protocol_id,
+            protocol_id=OefSearchMessage.protocol_id,
             message=msg_bytes,
         )
         cls.multiplexer1.put(envelope)
@@ -574,17 +481,16 @@ class TestFilteredSearchResult:
         service_description = Description(
             {"foo": 1, "bar": "baz"}, data_model=cls.data_model_barfoo
         )
-        register_service_request = OEFMessage(
-            type=OEFMessage.Type.REGISTER_SERVICE,
-            id=request_id,
+        register_service_request = OefSearchMessage(
+            performative=OefSearchMessage.Performative.REGISTER_SERVICE,
+            dialogue_reference=(str(request_id), ""),
             service_description=service_description,
-            service_id=service_id,
         )
-        msg_bytes = OEFSerializer().encode(register_service_request)
+        msg_bytes = OefSearchSerializer().encode(register_service_request)
         envelope = Envelope(
             to=DEFAULT_OEF,
             sender=cls.address_2,
-            protocol_id=OEFMessage.protocol_id,
+            protocol_id=OefSearchMessage.protocol_id,
             message=msg_bytes,
         )
         cls.multiplexer2.put(envelope)
@@ -594,17 +500,16 @@ class TestFilteredSearchResult:
         service_description = Description(
             {"foo": 1, "bar": "baz"}, data_model=data_model
         )
-        msg = OEFMessage(
-            type=OEFMessage.Type.UNREGISTER_SERVICE,
-            id=0,
+        msg = OefSearchMessage(
+            performative=OefSearchMessage.Performative.UNREGISTER_SERVICE,
+            dialogue_reference=(str(1), ""),
             service_description=service_description,
-            service_id="Test_service",
         )
-        msg_bytes = OEFSerializer().encode(msg)
+        msg_bytes = OefSearchSerializer().encode(msg)
         envelope = Envelope(
             to=DEFAULT_OEF,
             sender=cls.address_1,
-            protocol_id=OEFMessage.protocol_id,
+            protocol_id=OefSearchMessage.protocol_id,
             message=msg_bytes,
         )
         cls.multiplexer1.put(envelope)
@@ -615,26 +520,28 @@ class TestFilteredSearchResult:
         query = Query(constraints=[], model=self.data_model_barfoo)
 
         # build and send the request
-        search_services_request = OEFMessage(
-            type=OEFMessage.Type.SEARCH_SERVICES, id=request_id, query=query
+        search_services_request = OefSearchMessage(
+            performative=OefSearchMessage.Performative.SEARCH_SERVICES,
+            dialogue_reference=(str(request_id), ""),
+            query=query,
         )
-        msg_bytes = OEFSerializer().encode(search_services_request)
+        msg_bytes = OefSearchSerializer().encode(search_services_request)
         envelope = Envelope(
             to=DEFAULT_OEF,
             sender=self.address_1,
-            protocol_id=OEFMessage.protocol_id,
+            protocol_id=OefSearchMessage.protocol_id,
             message=msg_bytes,
         )
         self.multiplexer1.put(envelope)
 
         # check the result
         response_envelope = InBox(self.multiplexer1).get(block=True, timeout=5.0)
-        assert response_envelope.protocol_id == OEFMessage.protocol_id
+        assert response_envelope.protocol_id == OefSearchMessage.protocol_id
         assert response_envelope.to == self.address_1
         assert response_envelope.sender == DEFAULT_OEF
-        search_result = OEFSerializer().decode(response_envelope.message)
-        assert search_result.get("type") == OEFMessage.Type.SEARCH_RESULT
-        assert search_result.get("agents") == [self.address_2]
+        search_result = OefSearchSerializer().decode(response_envelope.message)
+        assert search_result.performative == OefSearchMessage.Performative.SEARCH_RESULT
+        assert search_result.agents == (self.address_2,)
 
     @classmethod
     def teardown_class(cls):
