@@ -53,11 +53,12 @@ from packages.fetchai.connections.oef.connection import (
     OEFObjectTranslator,
 )
 from packages.fetchai.protocols.fipa import fipa_pb2
-from packages.fetchai.protocols.fipa.message import FIPAMessage
-from packages.fetchai.protocols.fipa.serialization import FIPASerializer
-from packages.fetchai.protocols.oef.message import OEFMessage
-from packages.fetchai.protocols.oef.serialization import DEFAULT_OEF, OEFSerializer
+from packages.fetchai.protocols.fipa.message import FipaMessage
+from packages.fetchai.protocols.fipa.serialization import FipaSerializer
+from packages.fetchai.protocols.oef_search.message import OefSearchMessage
+from packages.fetchai.protocols.oef_search.serialization import OefSearchSerializer
 
+DEFAULT_OEF = "default_oef"
 
 logger = logging.getLogger(__name__)
 
@@ -140,53 +141,61 @@ class TestOEF:
             search_query_empty_model = Query(
                 [Constraint("foo", ConstraintType("==", "bar"))], model=None
             )
-            search_request = OEFMessage(
-                type=OEFMessage.Type.SEARCH_SERVICES,
-                id=request_id,
+            search_request = OefSearchMessage(
+                performative=OefSearchMessage.Performative.SEARCH_SERVICES,
+                dialogue_reference=(str(request_id), ""),
                 query=search_query_empty_model,
             )
             self.multiplexer.put(
                 Envelope(
                     to=DEFAULT_OEF,
                     sender=self.crypto1.address,
-                    protocol_id=OEFMessage.protocol_id,
-                    message=OEFSerializer().encode(search_request),
+                    protocol_id=OefSearchMessage.protocol_id,
+                    message=OefSearchSerializer().encode(search_request),
                 )
             )
 
             envelope = self.multiplexer.get(block=True, timeout=5.0)
-            search_result = OEFSerializer().decode(envelope.message)
-            assert search_result.get("type") == OEFMessage.Type.SEARCH_RESULT
-            assert search_result.get("id")
-            assert request_id and search_result.get("agents") == []
+            search_result = OefSearchSerializer().decode(envelope.message)
+            assert (
+                search_result.performative
+                == OefSearchMessage.Performative.SEARCH_RESULT
+            )
+            assert search_result.dialogue_reference[0] == str(request_id)
+            assert request_id and search_result.agents == ()
 
         def test_search_services_with_query_with_model(self):
             """Test that a search services request can be sent correctly.
 
             In this test, the query has a simple data model.
             """
-            request_id = 2
+            request_id = 1
             data_model = DataModel("foobar", [Attribute("foo", str, True)])
             search_query = Query(
                 [Constraint("foo", ConstraintType("==", "bar"))], model=data_model
             )
-            search_request = OEFMessage(
-                type=OEFMessage.Type.SEARCH_SERVICES, id=request_id, query=search_query
+            search_request = OefSearchMessage(
+                performative=OefSearchMessage.Performative.SEARCH_SERVICES,
+                dialogue_reference=(str(request_id), ""),
+                query=search_query,
             )
             self.multiplexer.put(
                 Envelope(
                     to=DEFAULT_OEF,
                     sender=self.crypto1.address,
-                    protocol_id=OEFMessage.protocol_id,
-                    message=OEFSerializer().encode(search_request),
+                    protocol_id=OefSearchMessage.protocol_id,
+                    message=OefSearchSerializer().encode(search_request),
                 )
             )
 
             envelope = self.multiplexer.get(block=True, timeout=5.0)
-            search_result = OEFSerializer().decode(envelope.message)
-            assert search_result.get("type") == OEFMessage.Type.SEARCH_RESULT
-            assert search_result.get("id") == request_id
-            assert search_result.get("agents") == []
+            search_result = OefSearchSerializer().decode(envelope.message)
+            assert (
+                search_result.performative
+                == OefSearchMessage.Performative.SEARCH_RESULT
+            )
+            assert search_result.dialogue_reference[0] == str(request_id)
+            assert search_result.agents == ()
 
         @classmethod
         def teardown_class(cls):
@@ -215,26 +224,27 @@ class TestOEF:
                 "foo", [Attribute("bar", int, True, "A bar attribute.")]
             )
             desc = Description({"bar": 1}, data_model=foo_datamodel)
-            msg = OEFMessage(
-                type=OEFMessage.Type.REGISTER_SERVICE,
-                id=1,
+            request_id = 1
+            msg = OefSearchMessage(
+                performative=OefSearchMessage.Performative.REGISTER_SERVICE,
+                dialogue_reference=(str(request_id), ""),
                 service_description=desc,
-                service_id="",
             )
-            msg_bytes = OEFSerializer().encode(msg)
+            msg_bytes = OefSearchSerializer().encode(msg)
             self.multiplexer.put(
                 Envelope(
                     to=DEFAULT_OEF,
                     sender=self.crypto1.address,
-                    protocol_id=OEFMessage.protocol_id,
+                    protocol_id=OefSearchMessage.protocol_id,
                     message=msg_bytes,
                 )
             )
             time.sleep(0.5)
 
-            search_request = OEFMessage(
-                type=OEFMessage.Type.SEARCH_SERVICES,
-                id=2,
+            request_id += 1
+            search_request = OefSearchMessage(
+                performative=OefSearchMessage.Performative.SEARCH_SERVICES,
+                dialogue_reference=(str(request_id), ""),
                 query=Query(
                     [Constraint("bar", ConstraintType("==", 1))], model=foo_datamodel
                 ),
@@ -243,17 +253,20 @@ class TestOEF:
                 Envelope(
                     to=DEFAULT_OEF,
                     sender=self.crypto1.address,
-                    protocol_id=OEFMessage.protocol_id,
-                    message=OEFSerializer().encode(search_request),
+                    protocol_id=OefSearchMessage.protocol_id,
+                    message=OefSearchSerializer().encode(search_request),
                 )
             )
             envelope = self.multiplexer.get(block=True, timeout=5.0)
-            search_result = OEFSerializer().decode(envelope.message)
-            assert search_result.get("type") == OEFMessage.Type.SEARCH_RESULT
-            assert search_result.get("id") == 2
-            if search_result.get("agents") != [self.crypto1.address]:
+            search_result = OefSearchSerializer().decode(envelope.message)
+            assert (
+                search_result.performative
+                == OefSearchMessage.Performative.SEARCH_RESULT
+            )
+            assert search_result.dialogue_reference[0] == str(request_id)
+            if search_result.agents != [self.crypto1.address]:
                 logger.warning(
-                    'search_result.get("agents") != [self.crypto1.address] FAILED in test_oef/test_communication.py'
+                    "search_result.agents != [self.crypto1.address] FAILED in test_oef/test_communication.py"
                 )
 
         @classmethod
@@ -288,18 +301,17 @@ class TestOEF:
                 "foo", [Attribute("bar", int, True, "A bar attribute.")]
             )
             cls.desc = Description({"bar": 1}, data_model=cls.foo_datamodel)
-            msg = OEFMessage(
-                type=OEFMessage.Type.REGISTER_SERVICE,
-                id=cls.request_id,
+            msg = OefSearchMessage(
+                performative=OefSearchMessage.Performative.REGISTER_SERVICE,
+                dialogue_reference=(str(cls.request_id), ""),
                 service_description=cls.desc,
-                service_id="",
             )
-            msg_bytes = OEFSerializer().encode(msg)
+            msg_bytes = OefSearchSerializer().encode(msg)
             cls.multiplexer.put(
                 Envelope(
                     to=DEFAULT_OEF,
                     sender=cls.crypto1.address,
-                    protocol_id=OEFMessage.protocol_id,
+                    protocol_id=OefSearchMessage.protocol_id,
                     message=msg_bytes,
                 )
             )
@@ -307,9 +319,9 @@ class TestOEF:
             time.sleep(1.0)
 
             cls.request_id += 1
-            search_request = OEFMessage(
-                type=OEFMessage.Type.SEARCH_SERVICES,
-                id=cls.request_id,
+            search_request = OefSearchMessage(
+                performative=OefSearchMessage.Performative.SEARCH_SERVICES,
+                dialogue_reference=(str(cls.request_id), ""),
                 query=Query(
                     [Constraint("bar", ConstraintType("==", 1))],
                     model=cls.foo_datamodel,
@@ -319,17 +331,20 @@ class TestOEF:
                 Envelope(
                     to=DEFAULT_OEF,
                     sender=cls.crypto1.address,
-                    protocol_id=OEFMessage.protocol_id,
-                    message=OEFSerializer().encode(search_request),
+                    protocol_id=OefSearchMessage.protocol_id,
+                    message=OefSearchSerializer().encode(search_request),
                 )
             )
             envelope = cls.multiplexer.get(block=True, timeout=5.0)
-            search_result = OEFSerializer().decode(envelope.message)
-            assert search_result.get("type") == OEFMessage.Type.SEARCH_RESULT
-            assert search_result.get("id") == cls.request_id
-            if search_result.get("agents") != [cls.crypto1.address]:
+            search_result = OefSearchSerializer().decode(envelope.message)
+            assert (
+                search_result.performative
+                == OefSearchMessage.Performative.SEARCH_RESULT
+            )
+            assert search_result.message_id == cls.request_id
+            if search_result.agents != [cls.crypto1.address]:
                 logger.warning(
-                    'search_result.get("agents") != [self.crypto1.address] FAILED in test_oef/test_communication.py'
+                    "search_result.agents != [self.crypto1.address] FAILED in test_oef/test_communication.py"
                 )
 
         def test_unregister_service(self):
@@ -341,18 +356,17 @@ class TestOEF:
             4. assert that no result is found.
             """
             self.request_id += 1
-            msg = OEFMessage(
-                type=OEFMessage.Type.UNREGISTER_SERVICE,
-                id=self.request_id,
+            msg = OefSearchMessage(
+                performative=OefSearchMessage.Performative.UNREGISTER_SERVICE,
+                dialogue_reference=(str(self.request_id), ""),
                 service_description=self.desc,
-                service_id="",
             )
-            msg_bytes = OEFSerializer().encode(msg)
+            msg_bytes = OefSearchSerializer().encode(msg)
             self.multiplexer.put(
                 Envelope(
                     to=DEFAULT_OEF,
                     sender=self.crypto1.address,
-                    protocol_id=OEFMessage.protocol_id,
+                    protocol_id=OefSearchMessage.protocol_id,
                     message=msg_bytes,
                 )
             )
@@ -360,9 +374,9 @@ class TestOEF:
             time.sleep(1.0)
 
             self.request_id += 1
-            search_request = OEFMessage(
-                type=OEFMessage.Type.SEARCH_SERVICES,
-                id=self.request_id,
+            search_request = OefSearchMessage(
+                performative=OefSearchMessage.Performative.SEARCH_SERVICES,
+                dialogue_reference=(str(self.request_id), ""),
                 query=Query(
                     [Constraint("bar", ConstraintType("==", 1))],
                     model=self.foo_datamodel,
@@ -372,16 +386,19 @@ class TestOEF:
                 Envelope(
                     to=DEFAULT_OEF,
                     sender=self.crypto1.address,
-                    protocol_id=OEFMessage.protocol_id,
-                    message=OEFSerializer().encode(search_request),
+                    protocol_id=OefSearchMessage.protocol_id,
+                    message=OefSearchSerializer().encode(search_request),
                 )
             )
 
             envelope = self.multiplexer.get(block=True, timeout=5.0)
-            search_result = OEFSerializer().decode(envelope.message)
-            assert search_result.get("type") == OEFMessage.Type.SEARCH_RESULT
-            assert search_result.get("id") == self.request_id
-            assert search_result.get("agents") == []
+            search_result = OefSearchSerializer().decode(envelope.message)
+            assert (
+                search_result.performative
+                == OefSearchMessage.Performative.SEARCH_RESULT
+            )
+            assert search_result.dialogue_reference[0] == str(self.request_id)
+            assert search_result.agents == ()
 
         @classmethod
         def teardown_class(cls):
@@ -412,25 +429,28 @@ class TestOEF:
             search_query_empty_model = Query(
                 [Constraint("foo", ConstraintType("==", "bar"))], model=None
             )
-            search_request = OEFMessage(
-                type=OEFMessage.Type.SEARCH_SERVICES,
-                id=request_id,
+            search_request = OefSearchMessage(
+                performative=OefSearchMessage.Performative.SEARCH_SERVICES,
+                dialogue_reference=(str(request_id), ""),
                 query=search_query_empty_model,
             )
             self.multiplexer.put(
                 Envelope(
                     to=DEFAULT_OEF,
                     sender=self.crypto1.address,
-                    protocol_id=OEFMessage.protocol_id,
-                    message=OEFSerializer().encode(search_request),
+                    protocol_id=OefSearchMessage.protocol_id,
+                    message=OefSearchSerializer().encode(search_request),
                 )
             )
 
             envelope = self.multiplexer.get(block=True, timeout=5.0)
-            search_result = OEFSerializer().decode(envelope.message)
-            assert search_result.get("type") == OEFMessage.Type.SEARCH_RESULT
-            assert search_result.get("id")
-            assert request_id and search_result.get("agents") == []
+            search_result = OefSearchSerializer().decode(envelope.message)
+            assert (
+                search_result.performative
+                == OefSearchMessage.Performative.SEARCH_RESULT
+            )
+            assert search_result.dialogue_reference[0] == str(request_id)
+            assert request_id and search_result.agents == ()
 
         @classmethod
         def teardown_class(cls):
@@ -470,11 +490,11 @@ class TestFIPA:
 
     def test_cfp(self):
         """Test that a CFP can be sent correctly."""
-        cfp_message = FIPAMessage(
-            message_id=0,
+        cfp_message = FipaMessage(
+            message_id=1,
             dialogue_reference=(str(0), ""),
             target=0,
-            performative=FIPAMessage.Performative.CFP,
+            performative=FipaMessage.Performative.CFP,
             query=Query([Constraint("something", ConstraintType(">", 1))]),
         )
         cfp_message.counterparty = self.crypto2.address
@@ -482,70 +502,68 @@ class TestFIPA:
             Envelope(
                 to=self.crypto2.address,
                 sender=self.crypto1.address,
-                protocol_id=FIPAMessage.protocol_id,
-                message=FIPASerializer().encode(cfp_message),
+                protocol_id=FipaMessage.protocol_id,
+                message=FipaSerializer().encode(cfp_message),
             )
         )
         envelope = self.multiplexer2.get(block=True, timeout=5.0)
-        expected_cfp_message = FIPASerializer().decode(envelope.message)
+        expected_cfp_message = FipaSerializer().decode(envelope.message)
         expected_cfp_message.counterparty = self.crypto2.address
 
         assert expected_cfp_message == cfp_message
 
-        cfp_none = FIPAMessage(
-            message_id=0,
+        cfp_none = FipaMessage(
+            message_id=1,
             dialogue_reference=(str(0), ""),
             target=0,
-            performative=FIPAMessage.Performative.CFP,
-            query=None,
+            performative=FipaMessage.Performative.CFP,
+            query=Query([Constraint("something", ConstraintType(">", 1))]),
         )
         cfp_none.counterparty = self.crypto2.address
         self.multiplexer1.put(
             Envelope(
                 to=self.crypto2.address,
                 sender=self.crypto1.address,
-                protocol_id=FIPAMessage.protocol_id,
-                message=FIPASerializer().encode(cfp_none),
+                protocol_id=FipaMessage.protocol_id,
+                message=FipaSerializer().encode(cfp_none),
             )
         )
         envelope = self.multiplexer2.get(block=True, timeout=5.0)
-        expected_cfp_none = FIPASerializer().decode(envelope.message)
+        expected_cfp_none = FipaSerializer().decode(envelope.message)
         expected_cfp_none.counterparty = self.crypto2.address
         assert expected_cfp_none == cfp_none
 
     def test_propose(self):
         """Test that a Propose can be sent correctly."""
-        propose_empty = FIPAMessage(
-            message_id=0,
+        propose_empty = FipaMessage(
+            message_id=1,
             dialogue_reference=(str(0), ""),
             target=0,
-            performative=FIPAMessage.Performative.PROPOSE,
-            proposal=[],
+            performative=FipaMessage.Performative.PROPOSE,
+            proposal=Description({"foo": "bar"}),
         )
         propose_empty.counterparty = self.crypto2.address
         self.multiplexer1.put(
             Envelope(
                 to=self.crypto2.address,
                 sender=self.crypto1.address,
-                protocol_id=FIPAMessage.protocol_id,
-                message=FIPASerializer().encode(propose_empty),
+                protocol_id=FipaMessage.protocol_id,
+                message=FipaSerializer().encode(propose_empty),
             )
         )
         envelope = self.multiplexer2.get(block=True, timeout=2.0)
-        expected_propose_empty = FIPASerializer().decode(envelope.message)
+        expected_propose_empty = FipaSerializer().decode(envelope.message)
         expected_propose_empty.counterparty = self.crypto2.address
         assert expected_propose_empty == propose_empty
 
-        propose_descriptions = FIPAMessage(
-            message_id=0,
+        propose_descriptions = FipaMessage(
+            message_id=1,
             dialogue_reference=(str(0), ""),
             target=0,
-            performative=FIPAMessage.Performative.PROPOSE,
-            proposal=[
-                Description(
-                    {"foo": "bar"}, DataModel("foobar", [Attribute("foo", str, True)])
-                )
-            ],
+            performative=FipaMessage.Performative.PROPOSE,
+            proposal=Description(
+                {"foo": "bar"}, DataModel("foobar", [Attribute("foo", str, True)])
+            ),
         )
 
         propose_descriptions.counterparty = self.crypto2.address
@@ -553,89 +571,89 @@ class TestFIPA:
             Envelope(
                 to=self.crypto2.address,
                 sender=self.crypto1.address,
-                protocol_id=FIPAMessage.protocol_id,
-                message=FIPASerializer().encode(propose_descriptions),
+                protocol_id=FipaMessage.protocol_id,
+                message=FipaSerializer().encode(propose_descriptions),
             )
         )
         envelope = self.multiplexer2.get(block=True, timeout=2.0)
-        expected_propose_descriptions = FIPASerializer().decode(envelope.message)
+        expected_propose_descriptions = FipaSerializer().decode(envelope.message)
         expected_propose_descriptions.counterparty = self.crypto2.address
         assert expected_propose_descriptions == propose_descriptions
 
     def test_accept(self):
         """Test that an Accept can be sent correctly."""
-        accept = FIPAMessage(
-            message_id=0,
+        accept = FipaMessage(
+            message_id=1,
             dialogue_reference=(str(0), ""),
             target=0,
-            performative=FIPAMessage.Performative.ACCEPT,
+            performative=FipaMessage.Performative.ACCEPT,
         )
         accept.counterparty = self.crypto2.address
         self.multiplexer1.put(
             Envelope(
                 to=self.crypto2.address,
                 sender=self.crypto1.address,
-                protocol_id=FIPAMessage.protocol_id,
-                message=FIPASerializer().encode(accept),
+                protocol_id=FipaMessage.protocol_id,
+                message=FipaSerializer().encode(accept),
             )
         )
         envelope = self.multiplexer2.get(block=True, timeout=2.0)
-        expected_accept = FIPASerializer().decode(envelope.message)
+        expected_accept = FipaSerializer().decode(envelope.message)
         expected_accept.counterparty = self.crypto2.address
         assert expected_accept == accept
 
     def test_match_accept(self):
         """Test that a match accept can be sent correctly."""
         # NOTE since the OEF SDK doesn't support the match accept, we have to use a fixed message id!
-        match_accept = FIPAMessage(
+        match_accept = FipaMessage(
             message_id=4,
             dialogue_reference=(str(0), ""),
             target=3,
-            performative=FIPAMessage.Performative.MATCH_ACCEPT,
+            performative=FipaMessage.Performative.MATCH_ACCEPT,
         )
         match_accept.counterparty = self.crypto2.address
         self.multiplexer1.put(
             Envelope(
                 to=self.crypto2.address,
                 sender=self.crypto1.address,
-                protocol_id=FIPAMessage.protocol_id,
-                message=FIPASerializer().encode(match_accept),
+                protocol_id=FipaMessage.protocol_id,
+                message=FipaSerializer().encode(match_accept),
             )
         )
         envelope = self.multiplexer2.get(block=True, timeout=2.0)
-        expected_match_accept = FIPASerializer().decode(envelope.message)
+        expected_match_accept = FipaSerializer().decode(envelope.message)
         expected_match_accept.counterparty = self.crypto2.address
         assert expected_match_accept == match_accept
 
     def test_decline(self):
         """Test that a Decline can be sent correctly."""
-        decline = FIPAMessage(
-            message_id=0,
+        decline = FipaMessage(
+            message_id=1,
             dialogue_reference=(str(0), ""),
             target=0,
-            performative=FIPAMessage.Performative.DECLINE,
+            performative=FipaMessage.Performative.DECLINE,
         )
         decline.counterparty = self.crypto2.address
         self.multiplexer1.put(
             Envelope(
                 to=self.crypto2.address,
                 sender=self.crypto1.address,
-                protocol_id=FIPAMessage.protocol_id,
-                message=FIPASerializer().encode(decline),
+                protocol_id=FipaMessage.protocol_id,
+                message=FipaSerializer().encode(decline),
             )
         )
         envelope = self.multiplexer2.get(block=True, timeout=2.0)
-        expected_decline = FIPASerializer().decode(envelope.message)
+        expected_decline = FipaSerializer().decode(envelope.message)
         expected_decline.counterparty = self.crypto2.address
         assert expected_decline == decline
 
     def test_match_accept_w_inform(self):
         """Test that a match accept with inform can be sent correctly."""
-        match_accept_w_inform = FIPAMessage(
-            message_id=0,
+        match_accept_w_inform = FipaMessage(
+            message_id=1,
             dialogue_reference=(str(0), ""),
             target=0,
-            performative=FIPAMessage.Performative.MATCH_ACCEPT_W_INFORM,
+            performative=FipaMessage.Performative.MATCH_ACCEPT_W_INFORM,
             info={"address": "my_address"},
         )
         match_accept_w_inform.counterparty = self.crypto2.address
@@ -643,22 +661,22 @@ class TestFIPA:
             Envelope(
                 to=self.crypto2.address,
                 sender=self.crypto1.address,
-                protocol_id=FIPAMessage.protocol_id,
-                message=FIPASerializer().encode(match_accept_w_inform),
+                protocol_id=FipaMessage.protocol_id,
+                message=FipaSerializer().encode(match_accept_w_inform),
             )
         )
         envelope = self.multiplexer2.get(block=True, timeout=2.0)
-        returned_match_accept_w_inform = FIPASerializer().decode(envelope.message)
+        returned_match_accept_w_inform = FipaSerializer().decode(envelope.message)
         returned_match_accept_w_inform.counterparty = self.crypto2.address
         assert returned_match_accept_w_inform == match_accept_w_inform
 
     def test_accept_w_inform(self):
         """Test that an accept with address can be sent correctly."""
-        accept_w_inform = FIPAMessage(
-            message_id=0,
+        accept_w_inform = FipaMessage(
+            message_id=1,
             dialogue_reference=(str(0), ""),
             target=0,
-            performative=FIPAMessage.Performative.ACCEPT_W_INFORM,
+            performative=FipaMessage.Performative.ACCEPT_W_INFORM,
             info={"address": "my_address"},
         )
         accept_w_inform.counterparty = self.crypto2.address
@@ -666,23 +684,23 @@ class TestFIPA:
             Envelope(
                 to=self.crypto2.address,
                 sender=self.crypto1.address,
-                protocol_id=FIPAMessage.protocol_id,
-                message=FIPASerializer().encode(accept_w_inform),
+                protocol_id=FipaMessage.protocol_id,
+                message=FipaSerializer().encode(accept_w_inform),
             )
         )
         envelope = self.multiplexer2.get(block=True, timeout=2.0)
-        returned_accept_w_inform = FIPASerializer().decode(envelope.message)
+        returned_accept_w_inform = FipaSerializer().decode(envelope.message)
         returned_accept_w_inform.counterparty = self.crypto2.address
         assert returned_accept_w_inform == accept_w_inform
 
     def test_inform(self):
         """Test that an inform can be sent correctly."""
         payload = {"foo": "bar"}
-        inform = FIPAMessage(
-            message_id=0,
+        inform = FipaMessage(
+            message_id=1,
             dialogue_reference=(str(0), ""),
             target=0,
-            performative=FIPAMessage.Performative.INFORM,
+            performative=FipaMessage.Performative.INFORM,
             info=payload,
         )
         inform.counterparty = self.crypto2.address
@@ -690,107 +708,97 @@ class TestFIPA:
             Envelope(
                 to=self.crypto2.address,
                 sender=self.crypto1.address,
-                protocol_id=FIPAMessage.protocol_id,
-                message=FIPASerializer().encode(inform),
+                protocol_id=FipaMessage.protocol_id,
+                message=FipaSerializer().encode(inform),
             )
         )
         envelope = self.multiplexer2.get(block=True, timeout=2.0)
-        returned_inform = FIPASerializer().decode(envelope.message)
+        returned_inform = FipaSerializer().decode(envelope.message)
         returned_inform.counterparty = self.crypto2.address
         assert returned_inform == inform
 
     def test_serialisation_fipa(self):
         """Tests a Value Error flag for wrong CFP query."""
         with pytest.raises(ValueError):
-            msg = FIPAMessage(
-                performative=FIPAMessage.Performative.CFP,
-                message_id=0,
-                dialogue_reference=(str(0), ""),
-                target=1,
-                query=None,
-            )
-            with mock.patch(
-                "packages.fetchai.protocols.fipa.message.FIPAMessage.Performative"
-            ) as mock_performative_enum:
-                mock_performative_enum.CFP.value = "unknown"
-                FIPASerializer().encode(msg), "Raises Value Error"
-        with pytest.raises(ValueError):
-            msg.set("query", "Hello")
-            # query type is not supported
-            FIPASerializer().encode(msg)
-        with pytest.raises(ValueError):
-            cfp_msg = FIPAMessage(
-                message_id=0,
+            msg = FipaMessage(
+                performative=FipaMessage.Performative.CFP,
+                message_id=1,
                 dialogue_reference=(str(0), ""),
                 target=0,
-                performative=FIPAMessage.Performative.CFP,
-                query=b"hello",
+                query=Query([Constraint("something", ConstraintType(">", 1))]),
+            )
+            with mock.patch(
+                "packages.fetchai.protocols.fipa.message.FipaMessage.Performative"
+            ) as mock_performative_enum:
+                mock_performative_enum.CFP.value = "unknown"
+                FipaSerializer().encode(msg), "Raises Value Error"
+        with pytest.raises(EOFError):
+            cfp_msg = FipaMessage(
+                message_id=1,
+                dialogue_reference=(str(0), ""),
+                target=0,
+                performative=FipaMessage.Performative.CFP,
+                query=Query([Constraint("something", ConstraintType(">", 1))]),
             )
             cfp_msg.set("query", "hello")
-            fipa_msg = fipa_pb2.FIPAMessage()
-            fipa_msg.message_id = cfp_msg.get("message_id")
-            dialogue_reference = cast(Dict[str, str], cfp_msg.get("dialogue_reference"))
+            fipa_msg = fipa_pb2.FipaMessage()
+            fipa_msg.message_id = cfp_msg.message_id
+            dialogue_reference = cast(Dict[str, str], cfp_msg.dialogue_reference)
             fipa_msg.dialogue_starter_reference = dialogue_reference[0]
             fipa_msg.dialogue_responder_reference = dialogue_reference[1]
-            fipa_msg.target = cfp_msg.get("target")
-            performative = fipa_pb2.FIPAMessage.CFP()
+            fipa_msg.target = cfp_msg.target
+            performative = fipa_pb2.FipaMessage.Cfp()
             fipa_msg.cfp.CopyFrom(performative)
             fipa_bytes = fipa_msg.SerializeToString()
 
             # The encoded message is not a valid FIPA message.
-            FIPASerializer().decode(fipa_bytes)
+            FipaSerializer().decode(fipa_bytes)
         with pytest.raises(ValueError):
-            cfp_msg = FIPAMessage(
-                message_id=0,
+            cfp_msg = FipaMessage(
+                message_id=1,
                 dialogue_reference=(str(0), ""),
                 target=0,
-                performative=FIPAMessage.Performative.CFP,
-                query=b"hello",
+                performative=FipaMessage.Performative.CFP,
+                query=Query([Constraint("something", ConstraintType(">", 1))]),
             )
             with mock.patch(
-                "packages.fetchai.protocols.fipa.message.FIPAMessage.Performative"
+                "packages.fetchai.protocols.fipa.message.FipaMessage.Performative"
             ) as mock_performative_enum:
                 mock_performative_enum.CFP.value = "unknown"
-                fipa_msg = fipa_pb2.FIPAMessage()
-                fipa_msg.message_id = cfp_msg.get("message_id")
-                dialogue_reference = cast(
-                    Dict[str, str], cfp_msg.get("dialogue_reference")
-                )
+                fipa_msg = fipa_pb2.FipaMessage()
+                fipa_msg.message_id = cfp_msg.message_id
+                dialogue_reference = cast(Dict[str, str], cfp_msg.dialogue_reference)
                 fipa_msg.dialogue_starter_reference = dialogue_reference[0]
                 fipa_msg.dialogue_responder_reference = dialogue_reference[1]
-                fipa_msg.target = cfp_msg.get("target")
-                performative = fipa_pb2.FIPAMessage.CFP()
+                fipa_msg.target = cfp_msg.target
+                performative = fipa_pb2.FipaMessage.Cfp()
                 fipa_msg.cfp.CopyFrom(performative)
                 fipa_bytes = fipa_msg.SerializeToString()
 
                 # The encoded message is not a FIPA message
-                FIPASerializer().decode(fipa_bytes)
+                FipaSerializer().decode(fipa_bytes)
 
     def test_on_oef_error(self):
         """Test the oef error."""
         oef_connection = self.multiplexer1.connections[0]
         oef_channel = oef_connection.channel
 
-        oef_channel.on_oef_error(answer_id=0, operation=OEFErrorOperation.SEARCH_AGENTS)
+        oef_channel.oef_msg_id += 1
+        dialogue_reference = ("1", str(oef_channel.oef_msg_id))
+        oef_channel.oef_msg_it_to_dialogue_reference[
+            oef_channel.oef_msg_id
+        ] = dialogue_reference
+        oef_channel.on_oef_error(
+            answer_id=oef_channel.oef_msg_id,
+            operation=OEFErrorOperation.SEARCH_SERVICES,
+        )
         envelope = self.multiplexer1.get(block=True, timeout=5.0)
-        dec_msg = OEFSerializer().decode(envelope.message)
+        dec_msg = OefSearchSerializer().decode(envelope.message)
+        assert dec_msg.dialogue_reference == ("1", str(oef_channel.oef_msg_id))
         assert (
-            dec_msg.get("type") is OEFMessage.Type.OEF_ERROR
+            dec_msg.performative is OefSearchMessage.Performative.OEF_ERROR
         ), "It should be an error message"
 
-    def test_on_dialogue_error(self):
-        """Test the dialogue error."""
-        oef_connection = self.multiplexer1.connections[0]
-        oef_connection = cast(OEFConnection, oef_connection)
-        oef_channel = oef_connection.channel
-
-        oef_channel.on_dialogue_error(answer_id=0, dialogue_id=0, origin="me")
-        envelope = self.multiplexer1.get(block=True, timeout=5.0)
-        dec_msg = OEFSerializer().decode(envelope.message)
-        assert (
-            dec_msg.get("type") is OEFMessage.Type.DIALOGUE_ERROR
-        ), "It should be a dialogue error"
-
     def test_send(self):
         """Test the send method."""
         envelope = Envelope(
@@ -983,18 +991,19 @@ async def test_send_oef_message(network_node):
         oef_port=10000,
         connection_id=PublicId("fetchai", "oef", "0.1.0"),
     )
+    request_id = 1
     oef_connection.loop = asyncio.get_event_loop()
     await oef_connection.connect()
-    msg = OEFMessage(
-        type=OEFMessage.Type.OEF_ERROR,
-        id=0,
-        operation=OEFMessage.OEFErrorOperation.SEARCH_AGENTS,
+    msg = OefSearchMessage(
+        performative=OefSearchMessage.Performative.OEF_ERROR,
+        dialogue_reference=(str(request_id), ""),
+        oef_error_operation=OefSearchMessage.OefErrorOperation.SEARCH_SERVICES,
     )
-    msg_bytes = OEFSerializer().encode(msg)
+    msg_bytes = OefSearchSerializer().encode(msg)
     envelope = Envelope(
         to=DEFAULT_OEF,
         sender=address,
-        protocol_id=OEFMessage.protocol_id,
+        protocol_id=OefSearchMessage.protocol_id,
         message=msg_bytes,
     )
     with pytest.raises(ValueError):
@@ -1003,12 +1012,17 @@ async def test_send_oef_message(network_node):
     data_model = DataModel("foobar", attributes=[])
     query = Query(constraints=[], model=data_model)
 
-    msg = OEFMessage(type=OEFMessage.Type.SEARCH_AGENTS, id=0, query=query)
-    msg_bytes = OEFSerializer().encode(msg)
+    request_id += 1
+    msg = OefSearchMessage(
+        performative=OefSearchMessage.Performative.SEARCH_SERVICES,
+        dialogue_reference=(str(request_id), ""),
+        query=query,
+    )
+    msg_bytes = OefSearchSerializer().encode(msg)
     envelope = Envelope(
         to=DEFAULT_OEF,
         sender=address,
-        protocol_id=OEFMessage.protocol_id,
+        protocol_id=OefSearchMessage.protocol_id,
         message=msg_bytes,
     )
     await oef_connection.send(envelope)
