@@ -23,19 +23,18 @@ from unittest import mock
 
 import pytest
 
-from packages.fetchai.protocols.tac.message import TACMessage
-from packages.fetchai.protocols.tac.serialization import (
-    TACSerializer,
-    _from_dict_to_pairs,
-)
+from packages.fetchai.protocols.tac.message import TacMessage
+from packages.fetchai.protocols.tac.serialization import TacSerializer
 
 
 def test_tac_message_instantiation():
     """Test instantiation of the tac message."""
-    assert TACMessage(type=TACMessage.Type.REGISTER, agent_name="some_name")
-    assert TACMessage(type=TACMessage.Type.UNREGISTER)
-    assert TACMessage(
-        type=TACMessage.Type.TRANSACTION,
+    assert TacMessage(
+        performative=TacMessage.Performative.REGISTER, agent_name="some_name"
+    )
+    assert TacMessage(performative=TacMessage.Performative.UNREGISTER)
+    assert TacMessage(
+        performative=TacMessage.Performative.TRANSACTION,
         tx_id="some_id",
         tx_sender_addr="some_address",
         tx_counterparty_addr="some_other_address",
@@ -47,10 +46,10 @@ def test_tac_message_instantiation():
         tx_sender_signature=b"some_signature",
         tx_counterparty_signature=b"some_other_signature",
     )
-    assert TACMessage(type=TACMessage.Type.GET_STATE_UPDATE)
-    assert TACMessage(type=TACMessage.Type.CANCELLED)
-    assert TACMessage(
-        type=TACMessage.Type.GAME_DATA,
+    assert TacMessage(performative=TacMessage.Performative.GET_STATE_UPDATE)
+    assert TacMessage(performative=TacMessage.Performative.CANCELLED)
+    assert TacMessage(
+        performative=TacMessage.Performative.GAME_DATA,
         amount_by_currency_id={"FET": 10},
         exchange_params_by_currency_id={"FET": 10.0},
         quantities_by_good_id={"good_1": 20, "good_2": 15},
@@ -60,34 +59,38 @@ def test_tac_message_instantiation():
         good_id_to_name={"good_1": "First good", "good_2": "Second good"},
         version_id="game_version_1",
     )
-    assert TACMessage(
-        type=TACMessage.Type.TRANSACTION_CONFIRMATION,
+    assert TacMessage(
+        performative=TacMessage.Performative.TRANSACTION_CONFIRMATION,
         tx_id="some_id",
         amount_by_currency_id={"FET": 10},
         quantities_by_good_id={"good_1": 20, "good_2": 15},
     )
-    assert TACMessage(
-        type=TACMessage.Type.TAC_ERROR, error_code=TACMessage.ErrorCode.GENERIC_ERROR
+    assert TacMessage(
+        performative=TacMessage.Performative.TAC_ERROR,
+        error_code=TacMessage.ErrorCode.GENERIC_ERROR,
+        info={"msg": "This is info msg."},
     )
-    assert str(TACMessage.Type.REGISTER) == "register"
+    assert str(TacMessage.Performative.REGISTER) == "register"
 
 
 def test_tac_serialization():
     """Test that the serialization for the tac message works."""
-    msg = TACMessage(type=TACMessage.Type.REGISTER, agent_name="some_name")
-    msg_bytes = TACSerializer().encode(msg)
-    actual_msg = TACSerializer().decode(msg_bytes)
+    msg = TacMessage(
+        performative=TacMessage.Performative.REGISTER, agent_name="some_name"
+    )
+    msg_bytes = TacSerializer().encode(msg)
+    actual_msg = TacSerializer().decode(msg_bytes)
     expected_msg = msg
     assert expected_msg == actual_msg
 
-    msg = TACMessage(type=TACMessage.Type.UNREGISTER)
-    msg_bytes = TACSerializer().encode(msg)
-    actual_msg = TACSerializer().decode(msg_bytes)
+    msg = TacMessage(performative=TacMessage.Performative.UNREGISTER)
+    msg_bytes = TacSerializer().encode(msg)
+    actual_msg = TacSerializer().decode(msg_bytes)
     expected_msg = msg
     assert expected_msg == actual_msg
 
-    msg = TACMessage(
-        type=TACMessage.Type.TRANSACTION,
+    msg = TacMessage(
+        performative=TacMessage.Performative.TRANSACTION,
         tx_id="some_id",
         tx_sender_addr="some_address",
         tx_counterparty_addr="some_other_address",
@@ -99,25 +102,25 @@ def test_tac_serialization():
         tx_sender_signature=b"some_signature",
         tx_counterparty_signature=b"some_other_signature",
     )
-    msg_bytes = TACSerializer().encode(msg)
-    actual_msg = TACSerializer().decode(msg_bytes)
+    msg_bytes = TacSerializer().encode(msg)
+    actual_msg = TacSerializer().decode(msg_bytes)
     expected_msg = msg
     assert expected_msg == actual_msg
 
-    msg = TACMessage(type=TACMessage.Type.GET_STATE_UPDATE)
-    msg_bytes = TACSerializer().encode(msg)
-    actual_msg = TACSerializer().decode(msg_bytes)
+    msg = TacMessage(performative=TacMessage.Performative.GET_STATE_UPDATE)
+    msg_bytes = TacSerializer().encode(msg)
+    actual_msg = TacSerializer().decode(msg_bytes)
     expected_msg = msg
     assert expected_msg == actual_msg
 
-    msg = TACMessage(type=TACMessage.Type.CANCELLED)
-    msg_bytes = TACSerializer().encode(msg)
-    actual_msg = TACSerializer().decode(msg_bytes)
+    msg = TacMessage(performative=TacMessage.Performative.CANCELLED)
+    msg_bytes = TacSerializer().encode(msg)
+    actual_msg = TacSerializer().decode(msg_bytes)
     expected_msg = msg
     assert expected_msg == actual_msg
 
-    msg = TACMessage(
-        type=TACMessage.Type.GAME_DATA,
+    msg = TacMessage(
+        performative=TacMessage.Performative.GAME_DATA,
         amount_by_currency_id={"FET": 10},
         exchange_params_by_currency_id={"FET": 10.0},
         quantities_by_good_id={"good_1": 20, "good_2": 15},
@@ -127,42 +130,37 @@ def test_tac_serialization():
         good_id_to_name={"good_1": "First good", "good_2": "Second good"},
         version_id="game_version_1",
     )
-    msg_bytes = TACSerializer().encode(msg)
-    actual_msg = TACSerializer().decode(msg_bytes)
+    msg_bytes = TacSerializer().encode(msg)
+    actual_msg = TacSerializer().decode(msg_bytes)
     expected_msg = msg
     assert expected_msg == actual_msg
 
-    msg = TACMessage(
-        type=TACMessage.Type.TRANSACTION_CONFIRMATION,
+    msg = TacMessage(
+        performative=TacMessage.Performative.TRANSACTION_CONFIRMATION,
         tx_id="some_id",
         amount_by_currency_id={"FET": 10},
         quantities_by_good_id={"good_1": 20, "good_2": 15},
     )
-    msg_bytes = TACSerializer().encode(msg)
-    actual_msg = TACSerializer().decode(msg_bytes)
+    msg_bytes = TacSerializer().encode(msg)
+    actual_msg = TacSerializer().decode(msg_bytes)
     expected_msg = msg
     assert expected_msg == actual_msg
 
-    with pytest.raises(ValueError, match="Type not recognized."):
+    with pytest.raises(
+        ValueError, match="Performative not valid: transaction_confirmation"
+    ):
         with mock.patch(
-            "packages.fetchai.protocols.tac.message.TACMessage.Type"
+            "packages.fetchai.protocols.tac.message.TacMessage.Performative"
         ) as mocked_type:
             mocked_type.TRANSACTION_CONFIRMATION.value = "unknown"
-            TACSerializer().encode(msg)
+            TacSerializer().encode(msg)
 
-    msg = TACMessage(
-        type=TACMessage.Type.TAC_ERROR,
-        error_code=TACMessage.ErrorCode.GENERIC_ERROR,
+    msg = TacMessage(
+        performative=TacMessage.Performative.TAC_ERROR,
+        error_code=TacMessage.ErrorCode.GENERIC_ERROR,
         info={"msg": "This is info msg."},
     )
-    msg_bytes = TACSerializer().encode(msg)
-    actual_msg = TACSerializer().decode(msg_bytes)
+    msg_bytes = TacSerializer().encode(msg)
+    actual_msg = TacSerializer().decode(msg_bytes)
     expected_msg = msg
     assert expected_msg == actual_msg
-
-
-def test_from_dict_to_pairs():
-    """Test the helper function _from_dict_to_pairs."""
-    with pytest.raises(ValueError):
-        test_items_dict = {"Test": b"UnsupportedType"}
-        _from_dict_to_pairs(test_items_dict)
